<?php
class YchClient {
	private $appkey;
	
	private $secret;
	
	public function __construct($appkey, $secret) {
		$this->appkey = $appkey;
		$this->secret = $secret;
	}

	public function send($url, $params) {
		if (empty($url) || empty($params) || empty($this->appkey) || empty($this->secret)) {
			return "Parameter error.";
		}
		
		foreach ($params as $key => $val) {
			if (!isset($val) || strtolower($val) == "null") {
				return $key . " is null.";
			}
		}
		
		$params["appKey"] = $this->appkey;
		return $this->doPost($url, $params);
	}

	//创建签名并发送请求
	private function doPost($url, $params) {
		//生成并添加签名
		$sign = $this->generateSign($params);
		$params["sign"] = $sign;
		
		//发送请求
		try {
			$resp = $this->sendRequest($url, $params);
			return $resp;
		} catch (Exception $e) {
			return 'http 请求错误,http 返回值' . $e->getCode();
		}
	}

	//根据参数生成签名
	private function generateSign($params) {
		ksort($params);

		$stringToBeSigned = $this->secret;
		foreach ($params as $key => $val) {
			$stringToBeSigned .= $key . $val;
		}

		$stringToBeSigned .= $this->secret;

		return md5($stringToBeSigned);
	}

	private function sendRequest($url, $postFields = null) {
		$ch = curl_init();
		curl_setopt($ch, CURLOPT_URL, $url);
		curl_setopt($ch, CURLOPT_FAILONERROR, false);
		curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);		
		curl_setopt($ch, CURLOPT_USERAGENT, "ych-sdk-php");
		curl_setopt($ch, CURLOPT_TIMEOUT, 15);
		curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 5);
		
		//https 请求
		if(strlen($url) > 5 && strtolower(substr($url, 0, 5)) == "https"){
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, false);
			curl_setopt($ch, CURLOPT_SSL_VERIFYHOST, 2);
		}

		if (is_array($postFields) && 0 < count($postFields)) {	
			$postBodyString = "";
			foreach ($postFields as $k => $v) {
				$postBodyString .= "$k=" . urlencode($v) . "&"; 				
			}

			unset($k, $v);
			curl_setopt($ch, CURLOPT_POST, true);
			
			$header = array("content-type: application/x-www-form-urlencoded; charset=UTF-8");
			curl_setopt($ch, CURLOPT_HTTPHEADER, $header);
			curl_setopt($ch, CURLOPT_POSTFIELDS, substr($postBodyString, 0, -1));				
		}

		$reponse = curl_exec($ch);
		
		if (curl_errno($ch)) {
			throw new Exception(curl_error($ch), 0);
		} else {
			$httpStatusCode = curl_getinfo($ch, CURLINFO_HTTP_CODE);
			if (200 !== $httpStatusCode) {
				throw new Exception($reponse, $httpStatusCode);
			}
		}

		curl_close($ch);
		return $reponse;
	}
}
?>


